@@ -1,12 +1,13 @@
 package Dist::Zilla::Plugin::Rinci::Validate;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2016-02-25'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Dmp;
 use Data::Sah;
 use Perinci::Sub::Normalize qw(normalize_function_metadata);
 
@@ -25,14 +26,6 @@ with (
     },
 );
 
-sub __squote {
-    require Data::Dumper;
-    my $res = Data::Dumper->new([shift])->
-        Purity(1)->Terse(1)->Deepcopy(1)->Indent(0)->Dump;
-    chomp $res;
-    $res;
-}
-
 sub __squish_code {
     my $code = shift;
     for ($code) {
@@ -201,12 +194,12 @@ sub munge_file {
                 push @code, "}";
                 if ($has_sch_default) {
                     push @code, " else { ";
-                    push @code,     "$kvar = ", __squote($sn->[1]{default}), ";";
+                    push @code,     "$kvar = ", dmp($sn->[1]{default}), ";";
                     push @code, "}";
                 }
             } elsif ($has_default_prop) {
                 # no schema is defined, but there is 'default' property
-                push @code, "$kvar //= ", __squote($as->{default}), ";";
+                push @code, "$kvar //= ", dmp($as->{default}), ";";
             }
 
             if ($as->{req}) {
@@ -349,7 +342,7 @@ Dist::Zilla::Plugin::Rinci::Validate - Insert argument validator code in output
 
 =head1 VERSION
 
-This document describes version 0.20 of Dist::Zilla::Plugin::Rinci::Validate (from Perl distribution Dist-Zilla-Plugin-Rinci-Validate), released on 2015-01-03.
+This document describes version 0.21 of Dist::Zilla::Plugin::Rinci::Validate (from Perl distribution Dist-Zilla-Plugin-Rinci-Validate), released on 2016-02-25.
 
 =head1 SYNOPSIS
 
@@ -489,7 +482,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Dist-Zilla-Plugin-Rinci-Validate>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-Validate>.
 
 =head1 BUGS
 
@@ -499,13 +492,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Dist::Zilla::Plugin::Rinci::Wrap>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
